Release notes
-------------

### Version v31.0.0


### Version v30.0.0

- Implement the new "vers" spec. This is a major incomplatible change.

- Add support for nginx version scheme
- Switching back to semver
- Improve origin and license documentation
- Add tests for carets in RPMs
- Format, streamline and refactor code
- Improve testing


### Version v21.4.9

- Add support Gentoo style versions. 


### Version v21.4.8

- Add support for more package types.
- Version classes are now hashable and frozen


### Version v21.4.6

- Initial Release
